Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(466)

Unified Diff: src/objects.h

Issue 766663003: harmony-classes: Implement 'super(...)' call syntactic restriction. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index c518240db1d34e4623525094b839f8886e756692..24679b8e1bce569511ca15d980a0a6b1607ca265 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -6831,9 +6831,13 @@ class SharedFunctionInfo: public HeapObject {
// False if the function definitely does not allocate an arguments object.
DECL_BOOLEAN_ACCESSORS(uses_arguments)
// Indicates that this function uses super. This is needed to set up the
rossberg 2014/11/27 19:04:40 Nit: ...uses a super property.
Dmitry Lomov (no reviews) 2014/11/27 19:41:57 Done. Russian has no articles, so I keep messing t
+ // the
// [[HomeObject]] on the function instance.
- DECL_BOOLEAN_ACCESSORS(uses_super)
+ DECL_BOOLEAN_ACCESSORS(uses_super_property)
+
+ // Indicates that this function uses super constructor.
rossberg 2014/11/27 19:04:40 Nit: ...uses the super constructor.
Dmitry Lomov (no reviews) 2014/11/27 19:41:57 Done.
+ DECL_BOOLEAN_ACCESSORS(uses_super_constructor_call)
// True if the function has any duplicated parameter names.
DECL_BOOLEAN_ACCESSORS(has_duplicate_parameters)
@@ -7112,7 +7116,8 @@ class SharedFunctionInfo: public HeapObject {
kOptimizationDisabled,
kStrictModeFunction,
kUsesArguments,
- kUsesSuper,
+ kUsesSuperProperty,
+ kUsesSuperConstructorCall,
kHasDuplicateParameters,
kNative,
kInlineBuiltin,
@@ -6831,9 +6831,13 @@ class SharedFunctionInfo: public HeapObject {
// False if the function definitely does not allocate an arguments object.
DECL_BOOLEAN_ACCESSORS(uses_arguments)
- // Indicates that this function uses super. This is needed to set up the
+ // Indicates that this function uses super property. This is needed to set up
rossberg 2014/11/27 19:04:40 Nit: ...uses a super property.
Dmitry Lomov (no reviews) 2014/11/27 19:41:57 Done. Russian has no articles, so I keep messing t

Powered by Google App Engine
This is Rietveld 408576698